﻿using System.Collections.Generic;
using System.Linq;
using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.Messaging;
using LocalJoost.Behaviours;

namespace DemoMessageBehaviour.Model
{
    public class DemoModel : ViewModelBase
    {
        public DemoModel()
        {
            if (IsInDesignMode)
            {
                // Code runs in Blend --> create design time data.
            }
            else
            {
                Messenger.Default.Register<FilesOpenedMessage>(
                    this,
                    DoOpenFileCallback);
            }
        }

        private void DoOpenFileCallback(FilesOpenedMessage msg)
        {
            if (msg.Identifier != "1234") return;
            SelectedFiles = msg.Content.Select(f => f.Name).ToList();
        }

        /// <summary>
        /// The <see cref="SelectedFiles" /> property's name.
        /// </summary>
        public const string SelectedFilesPropertyName = "SelectedFiles";

        private IList<string> _selectedFiles;

        /// <summary>
        /// Gets the SelectedFiles property.
        /// Changes to that property's value raise the PropertyChanged event. 
        /// </summary>
        public IList<string> SelectedFiles
        {
            get
            {
                return _selectedFiles;
            }

            set
            {
                if (_selectedFiles == value)
                {
                    return;
                }
                _selectedFiles = value;

                // Update bindings, no broadcast
                RaisePropertyChanged(SelectedFilesPropertyName);
            }
        }

        public bool CanOpen
        {
            get
            {
                return true; //some condition }
            }
        }
    }
}
