﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Interactivity;
using GalaSoft.MvvmLight.Messaging;

namespace LocalJoost.Behaviours
{
    /// <summary>
    /// A behavior attaching to a button
    /// </summary>
    public class FileOpenBehavior : Behavior<Button>
    {
        // Properties - can be set from XAML
        public string MessageIdentifier { get; set; }
        public string Filter { get; set; }
        public bool MultiSelect { get; set; }

        protected override void OnAttached()
        {
            base.OnAttached();
            Filter = "All files (*.*)|*.*";
            AssociatedObject.Click += AssociatedObject_Click;
        }

        void AssociatedObject_Click(object sender, RoutedEventArgs e)
        {
            // Open the dialog and send the message
            var dialog = 
                new OpenFileDialog {Filter = Filter, Multiselect = MultiSelect};
            if (dialog.ShowDialog() == true)
            {
                Messenger.Default.Send(
                    new FilesOpenedMessage(dialog.Files) 
                    { Identifier = MessageIdentifier });
            }            
        }

        protected override void OnDetaching()
        {
            AssociatedObject.Click -= AssociatedObject_Click;
            base.OnDetaching();
        }
    }
}
